@@ -3,9 +3,12 @@
 """
 Miscellaneous helper functions.
 """
+import inspect
 import os
 import sys
 
+from math import log
+
 
 def format_size(num: int, align=False, default='{} BYTE') -> str:
     """
@@ -109,3 +112,72 @@ def documentation(unit):
     docs = inspect.getdoc(unit)
     docs = re.sub(R'`refinery\.(?:\w+\.)*(\w+)`', R'\1', docs)
     return docs.replace('`', '')
+
+
+def skipfirst(iterable):
+    """
+    Returns an interable where the first element of the input iterable was
+    skipped.
+    """
+    it = iter(iterable)
+    next(it)
+    yield from it
+
+
+def autoinvoke(method, keywords: dict):
+    """
+    For each parameter that `method` expects, this function looks for an entry
+    in `keywords` which has the same name as that parameter. `autoinvoke` then
+    calls `method` with all matching parameters forwarded in the appropriate
+    manner.
+    """
+
+    kwdargs = {}
+    posargs = []
+    varargs = []
+
+    for p in inspect.signature(method).parameters.values():
+        try:
+            value = keywords[p.name]
+        except KeyError:
+            continue
+        if p.kind in (p.POSITIONAL_ONLY, p.POSITIONAL_OR_KEYWORD):
+            posargs.append(value)
+        elif p.kind is p.VAR_POSITIONAL:
+            varargs = value
+        elif p.kind is p.KEYWORD_ONLY:
+            kwdargs[p.name] = value
+
+    return method(*posargs, *varargs, **kwdargs)
+
+
+def entropy(data: bytearray) -> float:
+    """
+    Computes the entropy of `data` over the alphabet of all bytes.
+    """
+    if not data: return 0.0
+
+    try:
+        import numpy
+    except ImportError:
+        histogram = {b: data.count(b) for b in range(0x100)}
+        p = 1. / len(data)
+        S = [histogram[b] * p for b in histogram]
+        return 0.0 + -sum(q * log(q, 2) for q in S if q) / 8.0
+    else:
+        value, counts = numpy.unique(data, return_counts=True)
+        probs = counts / len(data)
+        # 8 bits are the maximum number of bits of information in a byte
+        return 0.0 + -sum(p * log(p, 2) for p in probs) / 8.0
+
+
+def isbuffer(obj) -> bool:
+    """
+    Test whether `obj` is an object that supports the buffer API, like a bytes
+    or bytearray object.
+    """
+    try:
+        with memoryview(obj):
+            return True
+    except TypeError:
+        return False
