@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from ...lib.argformats import multibin
-from . import BlockTransformation
+from . import arg, BlockTransformation
 
 
 class transpose(BlockTransformation):
@@ -9,10 +8,11 @@ class transpose(BlockTransformation):
     Interprets the sequence of blocks as rows of a matrix and returns the
     blocks that correspond to the columns of this matrix.
     """
-    def interface(self, argp):
-        argp.add_argument('padding', type=multibin, default=None, nargs='?',
-            help='Optional byte sequence to use as padding for tail end.')
-        return super().interface(argp)
+    def __init__(
+        self, padding: arg.help('Optional byte sequence to use as padding for tail end.') = B'',
+        bigendian=False, blocksize=1
+    ):
+        super().__init__(bigendian=bigendian, blocksize=blocksize, padding=padding)
 
     def process(self, data):
         rest = self.rest(data)
