@@ -5,12 +5,13 @@ Pattern matching based extraction and substitution units.
 """
 import re
 
-from typing import Dict, Tuple, Iterable, Optional, Callable, Union, ByteString
+from typing import Iterable, Optional, Callable, Union, ByteString
 from itertools import islice
+from hashlib import blake2b
 
 from ...lib.types import INF, AST
-from ...lib.argformats import number, regexp
-from .. import Unit
+from ...lib.argformats import regexp
+from .. import arg, Unit
 
 
 def _lazy_load(cmd: bytes):
@@ -72,7 +73,7 @@ def TransformSubstitutionFactory(fmt):
     try:
         fmt = fmt.decode('UNICODE_ESCAPE')
     except AttributeError:
-        if type(fmt) != str:
+        if not isinstance(fmt, str):
             raise
 
     fmt = fmt.encode('UTF8')
@@ -131,9 +132,31 @@ def TransformSubstitutionFactory(fmt):
     return transformation
 
 
-class AbstractRegexUnit(Unit, abstract=True):
+class PatternExtractorBase(Unit, abstract=True):
 
-    def matches(self, data: ByteString, pattern: Union[ByteString, re.Pattern], ascii: bool = True, utf16: bool = True):
+    def __init__(
+        self,
+        min        : arg.number('-n', help='Matches must have length at least N.') = 1,
+        max        : arg.number('-N', help='Matches must have length at most N.') = None,
+        len        : arg.number('-E', help='Matches must be of length N.') = None,
+        stripspace : arg.switch('-S', help='Strip all whitespace from input data.') = False,
+        unique     : arg.switch('-q', help='Yield every (transformed) Match only once.') = False,
+        longest    : arg.switch('-l', help='Sort results by length before picking.') = False,
+        take       : arg.number('-t', help='Return only the first N occurrences.') = None,
+    ):
+        super().__init__(
+            min=min,
+            max=max or INF,
+            len=len or AST,
+            stripspace=stripspace,
+            unique=unique,
+            ascii=True,
+            utf16=True,
+            longest=longest,
+            take=take or INF
+        )
+
+    def matches(self, data: ByteString, pattern: Union[ByteString, re.Pattern]):
         """
         Searches the input data for the given regular expression pattern. If the
         argument `utf16` is `True`, search for occurrences where a zero byte
@@ -142,106 +165,61 @@ class AbstractRegexUnit(Unit, abstract=True):
         """
         if not isinstance(pattern, re.Pattern):
             pattern = re.compile(pattern)
-        if ascii:
+        if self.args.ascii:
             yield from pattern.finditer(data)
-        if utf16:
-            d0 = data[0::2]
-            d1 = data[1::2]
-            for match in pattern.finditer(d0):
-                if not any(d1[match.start() + 0 : match.end() + 0]):
-                    yield match
-            for match in pattern.finditer(d1):
-                if not any(d0[match.start() + 1 : match.end() + 1]):
+        if self.args.utf16:
+            for zm in re.findall(BR'(?:.\0)+', data):
+                for match in pattern.finditer(zm[::2]):
                     yield match
 
-
-class PatternExtractorBase(AbstractRegexUnit, abstract=True):
-
-    def interface(self, argp):
-        argp = super().interface(argp)
-
-        filters = argp.add_argument_group('Match Filters')
-        filters.add_argument('-n', '--min', type=number, metavar='N', default=1, help='Matches must have length at least N.')
-        filters.add_argument('-N', '--max', type=number, metavar='N', default=INF, help='Matches must have length at most N.')
-        filters.add_argument('-E', '--len', type=number, metavar='N', default=AST, help='Matches must be of length N.')
-        filters.add_argument('-w', '--whitespace', action='store_true', help='Strip all whitespace from input data.')
-        filters.add_argument('-q', '--unique', action='store_true', help='Yield every (transformed) Match only once.')
-
-        filters.set_defaults(ascii=True, utf16=True)
-
-        selectors = argp.add_argument_group('Match Selectors')
-        selectors.add_argument('-l', '--longest', action='store_true',
-            help='Sort results by length before picking.')
-
-        mode = selectors.add_mutually_exclusive_group()
-        mode.add_argument('-t', '--take', type=number[1:], metavar='N', default=INF,
-            help='Return the first N occurrences.')
-        mode.add_argument('-p', '--pick', type=number, metavar='k', default=None,
-            help='Pick the pattern occurrence at index k, starting at 0.')
-
-        return filters
+    def matchfilter(self, hits: Iterable[ByteString]) -> Iterable[ByteString]:
+        barrier = set()
+        taken = 0
+        for hit in hits:
+            if not hit or len(hit) != self.args.len or len(hit) < self.args.min or len(hit) > self.args.max:
+                continue
+            if self.args.unique:
+                uid = blake2b(hit, digest_size=8)
+                if uid in barrier:
+                    continue
+                barrier.add(uid)
+            yield hit
+            taken += 1
+            if not self.args.longest and taken >= self.args.take:
+                break
 
     def matches_filtered(
         self,
         data: ByteString,
         pattern: Union[ByteString, re.Pattern],
-        transforms: Optional[Iterable[Union[ByteString, Callable[[re.Match], ByteString]]]] = None,
-        early_abort: bool = True
-    ) -> Iterable[Tuple[Tuple[int, int], bytes]]:
+        transforms: Optional[Iterable[Union[ByteString, Callable[[re.Match], ByteString]]]] = None
+    ) -> Iterable[ByteString]:
         """
         This is a wrapper for `AbstractRegexUint.matches` which filters the
         results according to the given commandline arguments. Returns a
         dictionary mapping its position (start, end) in the input data to the
         filtered and transformed match that was found at this position.
         """
-        barrier = set()
-        taken = 0
         transforms = transforms or [lambda m: m.group(0)]
-
-        if self.args.whitespace:
+        if self.args.stripspace:
             data = re.sub(BR'\s+', B'', data)
-        for match in self.matches(data, pattern, self.args.ascii, self.args.utf16):
-            for transform in transforms:
-                hit = transform(match) if callable(transform) else transform
-                if hit is None or len(hit) != self.args.len or len(hit) < self.args.min or len(hit) > self.args.max:
-                    continue
-                if self.args.unique:
-                    uid = hash(hit)
-                    if uid in barrier:
-                        continue
-                    barrier.add(uid)
-                yield match.span(), hit
-                if early_abort:
-                    taken += 1
-                    if not self.args.longest and taken >= self.args.take:
-                        break
+        yield from self.matchfilter(
+            transform(match) if callable(transform) else transform
+            for match in self.matches(memoryview(data), pattern)
+            for transform in transforms
+        )
 
-    def matches_filtered_cached(
-        self,
-        data: ByteString,
-        pattern: Union[ByteString, re.Pattern],
-        transforms: Optional[Iterable[Union[ByteString, Callable[[re.Match], ByteString]]]] = None,
-        early_abort: bool = True,
-        matches: Optional[dict] = None,
-    ) -> Dict[Tuple[int, int], bytes]:
-        if matches is None:
-            matches = {}
-        matches.update(self.matches_filtered(data, pattern, transforms, early_abort))
-        return matches
-
-    def matches_finalize(self, matches: Iterable[Tuple[Tuple[int, int], bytes]]) -> Iterable[bytes]:
+    def matches_finalize(self, matches: Iterable[ByteString]) -> Iterable[ByteString]:
         """
         Returns the final result of a dictionary of matches according to the
         settings provided via the command line interface.
         """
-        result = (d for _, d in matches)
+        result = matches
         if self.args.longest:
             result = sorted(result, key=len, reverse=True)
         if self.args.take:
             end = None if self.args.take is INF else self.args.take
             result = islice(result, end)
-        if self.args.pick:
-            result = islice(result, self.args.pick, self.args.pick + 1)
         yield from result
 
     def matches_processed(
@@ -249,7 +227,7 @@ class PatternExtractorBase(AbstractRegexUnit, abstract=True):
         data: ByteString,
         pattern: Union[ByteString, re.Pattern],
         transforms: Optional[Iterable[Union[ByteString, Callable[[re.Match], ByteString]]]] = None
-    ) -> Iterable[bytes]:
+    ) -> Iterable[ByteString]:
         """
         A convenience function that acts as the composition of:
 
@@ -260,61 +238,53 @@ class PatternExtractorBase(AbstractRegexUnit, abstract=True):
 
 
 class PatternExtractor(PatternExtractorBase, abstract=True):
-    def interface(self, argp):
-        filters = super().interface(argp)
-        switch = filters.add_mutually_exclusive_group()
-        switch.add_argument(
-            '-u', '--only-utf16',
-            action='store_false',
-            dest='ascii',
-            help='Search for UTF16 encoded patterns only.'
+    def __init__(
+        self, min=1, max=None, len=None, stripspace=False, unique=False, longest=False, take=None,
+        ascii: arg.switch('-u', '--no-ascii', group='AvsU', help='Search for UTF16 encoded patterns only.') = True,
+        utf16: arg.switch('-a', '--no-utf16', group='AvsU', help='Search for ASCII encoded patterns only.') = True,
+    ):
+        super().__init__(
+            min=min,
+            max=max,
+            len=len,
+            stripspace=stripspace,
+            unique=unique,
+            longest=longest,
+            take=take
         )
-        switch.add_argument(
-            '-a', '--only-ascii',
-            action='store_false',
-            dest='utf16',
-            help='Search for ASCII encoded patterns only.'
-        )
-        return argp
+        self.args.ascii = ascii
+        self.args.utf16 = utf16
 
 
 class RegexUnit(PatternExtractorBase, abstract=True):
 
-    def interface(self, argp, regex_default=None):
-        mode = argp.add_argument_group(
-            'Regular Expression Flags',
-            'The DOTALL flag is set by default and has to be '
-            'disabled rather than enabled.'
+    def __init__(
+        self, regex : arg(type=regexp, help='Regular expression to match.'),
+        # TODO: Use positional only in Python 3.8
+        # /,
+        multiline   : arg.switch('-M', help='Caret and dollar match the beginning and end of '
+                                            'a line, a dot does not match line breaks.') = False,
+        ignorecase  : arg.switch('-I', help='Ignore capitalization for alphabetic characters.') = False,
+        utf16       : arg.switch('-u', help='Search for unicode patterns instead of ascii.') = False,
+        min=1, max=None, len=None, stripspace=False, unique=False, longest=False, take=None
+    ):
+        super().__init__(
+            min=min,
+            max=max,
+            len=len,
+            stripspace=stripspace,
+            unique=unique,
+            longest=longest,
+            take=take
         )
-        mode.add_argument('-M', '--multiline', action='store_const', default=B'', const=B'm')
-        mode.add_argument('-A', '--notdotall', dest='dotall', action='store_const', default=B's', const=B'')
-        mode.add_argument('-I', '--ignorecase', action='store_const', default=B'', const=B'i')
 
-        regex = dict(
-            type=regexp,
-            help='Regular expression to match.'
-        )
-        if regex_default:
-            regex.update(dict(
-                default=regex_default,
-                nargs='?'
-            ))
+        self.args.utf16 = utf16
+        self.args.ascii = not utf16
 
-        argp.add_argument('regex', **regex)
+        regex_flags = B'm' if multiline else B's'
+        if ignorecase: regex_flags += B'i'
 
-        filters = super().interface(argp)
-        filters.add_argument(
-            '-u', '--utf16',
-            action='store_true',
-            default=False,
-            help='Search for UTF-16 encoded patterns instead of ASCII.'
-        )
-        return argp
+        if isinstance(regex, str):
+            regex = regex.encode(self.codec)
 
-    def __init__(self, *args, **kw):
-        super().__init__(*args, **kw)
-        self.args.ascii = not self.args.utf16
-        flags = B''.join(getattr(self.args, flag)
-            for flag in ('ignorecase', 'multiline', 'dotall'))
-        if flags:
-            self.args.regex = B'(?%s)%s' % (flags, self.args.regex)
+        self.args.regex = B'(?%s)%s' % (regex_flags, regex)
