@@ -5,8 +5,9 @@ import re
 from fnmatch import fnmatch
 from ipaddress import ip_address
 from urllib.parse import urlparse
+from string import ascii_letters
 
-from . import PatternExtractor
+from . import arg, PatternExtractor
 from .. import RefineryCriticalException
 from ...lib.patterns import indicators
 
@@ -20,6 +21,36 @@ class xtp(PatternExtractor):
     data, use `refinery.carve`.
     """
 
+    @arg('pattern', type=str, default=('hostname', 'url', 'email'), help=(
+        'Choose the pattern to extract, defaults are hostname, url, and email. '
+        'Use an asterix character to select all available patterns. The available '
+        'patterns are: {}'.format(', '.join(p.name for p in indicators))))
+    @arg.switch('-f', dest='filter', help=(
+        'If this setting is enabled, the xtp unit will attempt to reduce the number '
+        'of false positives by certain crude heuristics.'))
+    def __init__(
+        self, *pattern, filter=False, min=1, max=None, len=None, stripspace=False,
+        unique=False, longest=False, take=None
+    ):
+        self.superinit(super(), **vars(), ascii=True, utf16=True)
+
+        patterns = {
+            p for name in pattern for p in indicators if fnmatch(p.name, name)
+        }
+        if indicators.hostname in patterns:
+            patterns.remove(indicators.hostname)
+            patterns.add(indicators.ipv4)
+            patterns.add(indicators.domain)
+        patterns = [F'(?P<{p.name}>{p.value})' for p in patterns]
+        if not patterns:
+            raise RefineryCriticalException('The given mask does not match any known indicator pattern.')
+        pattern = '|'.join(patterns)
+        self.log_debug(F'using pattern: {pattern}')
+
+        self.args.pattern = re.compile(pattern.encode(self.codec))
+        self.args.filter = filter
+
+    _ALPHABETIC = ascii_letters.encode('ASCII')
     _LEGITIMATE_HOSTS = [
         'adobe.com',
         'aka.ms',
@@ -58,35 +89,6 @@ class xtp(PatternExtractor):
         'wscript.shell',
     ]
 
-    def interface(self, argp):
-        argp.add_argument('-f', '--filter', action='store_true', help=(
-            'If this setting is enabled, the xtp unit will attempt to reduce the number '
-            'of false positives by certain crude heuristics.'))
-        argp.add_argument('pattern', metavar='PATTERN', type=str, nargs='*',
-            default=['hostname', 'url', 'email'], help=(
-                'Choose the pattern to extract, defaults are hostname, url, and email. '
-                'Use an asterix character to select all available patterns. The available '
-                'patterns are: {}'.format(', '.join(p.name for p in indicators))
-            )
-        )
-        return super().interface(argp)
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        patterns = {
-            p for name in self.args.pattern for p in indicators if fnmatch(p.name, name)
-        }
-        if indicators.hostname in patterns:
-            patterns.remove(indicators.hostname)
-            patterns.add(indicators.ipv4)
-            patterns.add(indicators.domain)
-        patterns = [F'(?P<{p.name}>{p.value})' for p in patterns]
-        if not patterns:
-            raise RefineryCriticalException('The given mask does not match any known indicator pattern.')
-        self.pattern = '|'.join(patterns)
-        self.log_debug(F'using pattern: {self.pattern}')
-        self.pattern = re.compile(self.pattern.encode(self.codec))
-
     @classmethod
     def _check_match(cls, data, pos, name, value):
         if name == 'ipv4':
@@ -122,8 +124,17 @@ class xtp(PatternExtractor):
                     return None
                 if any(x.startswith('_') for x in hostparts):
                     return None
-                if len(hostparts[-1]) > 3 and len(set(re.findall(R'{}(?:\.\w+)+'.format(hostparts[0]).encode('ascii'), data))) > 2:
-                    return None
+                if len(hostparts[-1]) > 3:
+                    seen_before = len(set(re.findall(
+                        R'{}(?:\.\w+)+'.format(hostparts[0]).encode('ascii'), data)))
+                    if seen_before > 2:
+                        return None
+        elif name == 'email':
+            at = value.find(B'@')
+            ix = 0
+            while value[ix] not in cls._ALPHABETIC:
+                ix += 1
+            return None if at - ix < 3 else value[ix:]
         elif name == 'path':
             if len(value) < 8:
                 return None
@@ -148,4 +159,4 @@ class xtp(PatternExtractor):
             whitelist.add(value)
 
         transforms = None if not self.args.filter else [check]
-        yield from self.matches_processed(data, self.pattern, transforms)
+        yield from self.matches_processed(memoryview(data), self.args.pattern, transforms)
