@@ -12,16 +12,17 @@ class ppjson(Unit):
     """
     Expects JSON input data and outputs it in a neatly formatted manner.
     """
-    _TRAILING_COMMA = R',\s*(}|])'
+    _TRAILING_COMMA = re.compile(R',\s*(}|])')
 
-    def interface(self, argp):
+    @classmethod
+    def interface(cls, argp):
         argp.add_argument('-i', '--indent', type=number, default=4,
             help='Controls the amount of space characters used for indentation in the output. Default is 4.')
         return super().interface(argp)
 
     @unicoded
     def process(self, data: str) -> str:
-        if re.search(self._TRAILING_COMMA, data):
+        if self._TRAILING_COMMA.search(data):
             from ...lib.patterns import formats
 
             strings = {
@@ -33,6 +34,6 @@ class ppjson(Unit):
                 k = match.start()
                 return match.group(0 if any(k in s for s in strings) else 1)
 
-            data = re.sub(self._TRAILING_COMMA, smartfix, data)
+            data = self._TRAILING_COMMA.sub(smartfix, data)
 
         return json.dumps(json.loads(data), indent=self.args.indent)
